var namespace_v_s_t_g_u_i =
[
    [ "Animation", "namespace_v_s_t_g_u_i_1_1_animation.html", "namespace_v_s_t_g_u_i_1_1_animation" ],
    [ "BitmapFilter", "namespace_v_s_t_g_u_i_1_1_bitmap_filter.html", "namespace_v_s_t_g_u_i_1_1_bitmap_filter" ],
    [ "Call", "namespace_v_s_t_g_u_i_1_1_call.html", [
      [ "FunctionCallback", "namespace_v_s_t_g_u_i_1_1_call.html#a8e79e769abdee84bcfcee4202d7aefdb", null ],
      [ "later", "namespace_v_s_t_g_u_i_1_1_call.html#af5c50081433f15f648dec99d9d160b47", null ]
    ] ],
    [ "CClipboardDetail", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail.html", "namespace_v_s_t_g_u_i_1_1_c_clipboard_detail" ],
    [ "CDrawMethods", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html", [
      [ "CreateTextTruncateFlags", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#ac8a55179c400af09bbd14cb3d4bbb13d", [
        [ "kReturnEmptyIfTruncationIsPlaceholderOnly", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#ac8a55179c400af09bbd14cb3d4bbb13da0ff19b5b98ca2119b2de270cea51eb9b", null ]
      ] ],
      [ "IconPosition", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a98d0b947f28f939706e11e28e9ff95e8", [
        [ "kIconLeft", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a98d0b947f28f939706e11e28e9ff95e8a3f3b68eb384b1f705c9a01801bc1f9f9", null ],
        [ "kIconCenterAbove", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a98d0b947f28f939706e11e28e9ff95e8a47c1ae3e0906aea8de34b624c21394ff", null ],
        [ "kIconCenterBelow", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a98d0b947f28f939706e11e28e9ff95e8a91342ea48d404293f9b1b384081597aa", null ],
        [ "kIconRight", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a98d0b947f28f939706e11e28e9ff95e8a91a1cbd7d5fd91550fa99a83ee15224e", null ]
      ] ],
      [ "TextTruncateMode", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a36004541822bde622ce804cf340c363c", [
        [ "kTextTruncateNone", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a36004541822bde622ce804cf340c363ca9c03e16132314e61e3bd5241cf61f47e", null ],
        [ "kTextTruncateHead", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a36004541822bde622ce804cf340c363ca05446ace477426fd6ffe4ccca1ccc510", null ],
        [ "kTextTruncateTail", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a36004541822bde622ce804cf340c363cad61305bee7d9f9b71305fd3cd9a05436", null ]
      ] ],
      [ "createTruncatedText", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#abbd3b5f90a5add94ae1272239025b6ed", null ],
      [ "drawIconAndText", "namespace_v_s_t_g_u_i_1_1_c_draw_methods.html#a9ecdd41e45eb5efc6f86e818a979a3e3", null ]
    ] ],
    [ "Constants", "namespace_v_s_t_g_u_i_1_1_constants.html", [
      [ "double_pi", "namespace_v_s_t_g_u_i_1_1_constants.html#ab98a248ac4106dbca2250f28257418b4", null ],
      [ "e", "namespace_v_s_t_g_u_i_1_1_constants.html#ab7374b6e3094e3cf3c26ef8d96348200", null ],
      [ "half_pi", "namespace_v_s_t_g_u_i_1_1_constants.html#a69a41e0dbe6bf390f6657434fe7efd38", null ],
      [ "ln2", "namespace_v_s_t_g_u_i_1_1_constants.html#a91138af4c200ad5c6bc923242b960388", null ],
      [ "pi", "namespace_v_s_t_g_u_i_1_1_constants.html#a95ed8d1f751904d69454dbb31f1f247d", null ],
      [ "quarter_pi", "namespace_v_s_t_g_u_i_1_1_constants.html#a86ff3c554c27235935416b5dce0e4e2b", null ],
      [ "sqrt2", "namespace_v_s_t_g_u_i_1_1_constants.html#a7387c99b57ee215aa7f0e1e198050302", null ]
    ] ],
    [ "Detail", "namespace_v_s_t_g_u_i_1_1_detail.html", null ],
    [ "EventPrivate", "namespace_v_s_t_g_u_i_1_1_event_private.html", [
      [ "counter", "namespace_v_s_t_g_u_i_1_1_event_private.html#a1944753ac8107ec537f75b7e0201d866", null ]
    ] ],
    [ "ExternalView", "namespace_v_s_t_g_u_i_1_1_external_view.html", "namespace_v_s_t_g_u_i_1_1_external_view" ],
    [ "Layouting", "namespace_v_s_t_g_u_i_1_1_layouting.html", "namespace_v_s_t_g_u_i_1_1_layouting" ],
    [ "PixelBuffer", "namespace_v_s_t_g_u_i_1_1_pixel_buffer.html", "namespace_v_s_t_g_u_i_1_1_pixel_buffer" ],
    [ "Standalone", "namespace_v_s_t_g_u_i_1_1_standalone.html", "namespace_v_s_t_g_u_i_1_1_standalone" ],
    [ "String", "namespace_v_s_t_g_u_i_1_1_string.html", [
      [ "free", "namespace_v_s_t_g_u_i_1_1_string.html#af30ee7f201c1f86d9aceb849d6d08fbf", null ],
      [ "newWithString", "namespace_v_s_t_g_u_i_1_1_string.html#a83745b23a3d48e4f1e69950977918803", null ]
    ] ],
    [ "UIDescriptionPrivate", "namespace_v_s_t_g_u_i_1_1_u_i_description_private.html", "namespace_v_s_t_g_u_i_1_1_u_i_description_private" ],
    [ "UIViewCreator", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator.html", "namespace_v_s_t_g_u_i_1_1_u_i_view_creator" ],
    [ "VST3EditorInternal", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html", [
      [ "parseSize", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#a3fa5e1ea61dc076815c8bf71f90cb502", null ],
      [ "releaseSubController", "namespace_v_s_t_g_u_i_1_1_v_s_t3_editor_internal.html#aa0f6b4288ac078c4728da6fe39ecf41e", null ]
    ] ],
    [ "Xml", "namespace_v_s_t_g_u_i_1_1_xml.html", "namespace_v_s_t_g_u_i_1_1_xml" ],
    [ "AEffGUIEditor", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_a_eff_g_u_i_editor" ],
    [ "AspectRatioVST3Editor", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_aspect_ratio_v_s_t3_editor" ],
    [ "Base64Codec", "class_v_s_t_g_u_i_1_1_base64_codec.html", "class_v_s_t_g_u_i_1_1_base64_codec" ],
    [ "BitScopeToggleT", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t.html", "struct_v_s_t_g_u_i_1_1_bit_scope_toggle_t" ],
    [ "Buffer", "class_v_s_t_g_u_i_1_1_buffer.html", "class_v_s_t_g_u_i_1_1_buffer" ],
    [ "BufferedOutputStream", "class_v_s_t_g_u_i_1_1_buffered_output_stream.html", "class_v_s_t_g_u_i_1_1_buffered_output_stream" ],
    [ "CAnimationSplashScreen", "class_v_s_t_g_u_i_1_1_c_animation_splash_screen.html", "class_v_s_t_g_u_i_1_1_c_animation_splash_screen" ],
    [ "CAnimKnob", "class_v_s_t_g_u_i_1_1_c_anim_knob.html", "class_v_s_t_g_u_i_1_1_c_anim_knob" ],
    [ "CAutoAnimation", "class_v_s_t_g_u_i_1_1_c_auto_animation.html", "class_v_s_t_g_u_i_1_1_c_auto_animation" ],
    [ "CAutoLayoutContainerView", "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view.html", "class_v_s_t_g_u_i_1_1_c_auto_layout_container_view" ],
    [ "CBaseObject", "class_v_s_t_g_u_i_1_1_c_base_object.html", "class_v_s_t_g_u_i_1_1_c_base_object" ],
    [ "CBaseObjectGuard", "class_v_s_t_g_u_i_1_1_c_base_object_guard.html", "class_v_s_t_g_u_i_1_1_c_base_object_guard" ],
    [ "CBitmap", "class_v_s_t_g_u_i_1_1_c_bitmap.html", "class_v_s_t_g_u_i_1_1_c_bitmap" ],
    [ "CBitmapPixelAccess", "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access.html", "class_v_s_t_g_u_i_1_1_c_bitmap_pixel_access" ],
    [ "CButtonState", "struct_v_s_t_g_u_i_1_1_c_button_state.html", "struct_v_s_t_g_u_i_1_1_c_button_state" ],
    [ "CCheckBox", "class_v_s_t_g_u_i_1_1_c_check_box.html", "class_v_s_t_g_u_i_1_1_c_check_box" ],
    [ "CClipboard", "struct_v_s_t_g_u_i_1_1_c_clipboard.html", "struct_v_s_t_g_u_i_1_1_c_clipboard" ],
    [ "CColor", "struct_v_s_t_g_u_i_1_1_c_color.html", "struct_v_s_t_g_u_i_1_1_c_color" ],
    [ "CColorChooser", "class_v_s_t_g_u_i_1_1_c_color_chooser.html", "class_v_s_t_g_u_i_1_1_c_color_chooser" ],
    [ "CColorChooserUISettings", "struct_v_s_t_g_u_i_1_1_c_color_chooser_u_i_settings.html", "struct_v_s_t_g_u_i_1_1_c_color_chooser_u_i_settings" ],
    [ "CCommandMenuItem", "class_v_s_t_g_u_i_1_1_c_command_menu_item.html", "class_v_s_t_g_u_i_1_1_c_command_menu_item" ],
    [ "CControl", "class_v_s_t_g_u_i_1_1_c_control.html", "class_v_s_t_g_u_i_1_1_c_control" ],
    [ "CDataBrowser", "class_v_s_t_g_u_i_1_1_c_data_browser.html", "class_v_s_t_g_u_i_1_1_c_data_browser" ],
    [ "CDragContainerHelper", "class_v_s_t_g_u_i_1_1_c_drag_container_helper.html", "class_v_s_t_g_u_i_1_1_c_drag_container_helper" ],
    [ "CDrawContext", "class_v_s_t_g_u_i_1_1_c_draw_context.html", "class_v_s_t_g_u_i_1_1_c_draw_context" ],
    [ "CDrawMode", "struct_v_s_t_g_u_i_1_1_c_draw_mode.html", "struct_v_s_t_g_u_i_1_1_c_draw_mode" ],
    [ "CDropSource", "class_v_s_t_g_u_i_1_1_c_drop_source.html", "class_v_s_t_g_u_i_1_1_c_drop_source" ],
    [ "CExternalControl", "class_v_s_t_g_u_i_1_1_c_external_control.html", "class_v_s_t_g_u_i_1_1_c_external_control" ],
    [ "CExternalView", "class_v_s_t_g_u_i_1_1_c_external_view.html", "class_v_s_t_g_u_i_1_1_c_external_view" ],
    [ "CExternalViewBaseImpl", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl.html", "struct_v_s_t_g_u_i_1_1_c_external_view_base_impl" ],
    [ "CFileExtension", "class_v_s_t_g_u_i_1_1_c_file_extension.html", "class_v_s_t_g_u_i_1_1_c_file_extension" ],
    [ "CFileStream", "class_v_s_t_g_u_i_1_1_c_file_stream.html", "class_v_s_t_g_u_i_1_1_c_file_stream" ],
    [ "CFontChooser", "class_v_s_t_g_u_i_1_1_c_font_chooser.html", "class_v_s_t_g_u_i_1_1_c_font_chooser" ],
    [ "CFontChooserUIDefinition", "struct_v_s_t_g_u_i_1_1_c_font_chooser_u_i_definition.html", "struct_v_s_t_g_u_i_1_1_c_font_chooser_u_i_definition" ],
    [ "CFontDesc", "class_v_s_t_g_u_i_1_1_c_font_desc.html", "class_v_s_t_g_u_i_1_1_c_font_desc" ],
    [ "CFrame", "class_v_s_t_g_u_i_1_1_c_frame.html", "class_v_s_t_g_u_i_1_1_c_frame" ],
    [ "CGradient", "class_v_s_t_g_u_i_1_1_c_gradient.html", "class_v_s_t_g_u_i_1_1_c_gradient" ],
    [ "CGradientView", "class_v_s_t_g_u_i_1_1_c_gradient_view.html", "class_v_s_t_g_u_i_1_1_c_gradient_view" ],
    [ "CGraphicsPath", "class_v_s_t_g_u_i_1_1_c_graphics_path.html", "class_v_s_t_g_u_i_1_1_c_graphics_path" ],
    [ "CGraphicsTransform", "struct_v_s_t_g_u_i_1_1_c_graphics_transform.html", "struct_v_s_t_g_u_i_1_1_c_graphics_transform" ],
    [ "CHorizontalSlider", "class_v_s_t_g_u_i_1_1_c_horizontal_slider.html", "class_v_s_t_g_u_i_1_1_c_horizontal_slider" ],
    [ "CHorizontalSwitch", "class_v_s_t_g_u_i_1_1_c_horizontal_switch.html", "class_v_s_t_g_u_i_1_1_c_horizontal_switch" ],
    [ "CInvalidRectList", "struct_v_s_t_g_u_i_1_1_c_invalid_rect_list.html", "struct_v_s_t_g_u_i_1_1_c_invalid_rect_list" ],
    [ "CKickButton", "class_v_s_t_g_u_i_1_1_c_kick_button.html", "class_v_s_t_g_u_i_1_1_c_kick_button" ],
    [ "CKnob", "class_v_s_t_g_u_i_1_1_c_knob.html", "class_v_s_t_g_u_i_1_1_c_knob" ],
    [ "CKnobBase", "class_v_s_t_g_u_i_1_1_c_knob_base.html", "class_v_s_t_g_u_i_1_1_c_knob_base" ],
    [ "CLayeredViewContainer", "class_v_s_t_g_u_i_1_1_c_layered_view_container.html", "class_v_s_t_g_u_i_1_1_c_layered_view_container" ],
    [ "CLineStyle", "class_v_s_t_g_u_i_1_1_c_line_style.html", "class_v_s_t_g_u_i_1_1_c_line_style" ],
    [ "CListControl", "class_v_s_t_g_u_i_1_1_c_list_control.html", "class_v_s_t_g_u_i_1_1_c_list_control" ],
    [ "CListControlRowDesc", "struct_v_s_t_g_u_i_1_1_c_list_control_row_desc.html", "struct_v_s_t_g_u_i_1_1_c_list_control_row_desc" ],
    [ "CMemoryStream", "class_v_s_t_g_u_i_1_1_c_memory_stream.html", "class_v_s_t_g_u_i_1_1_c_memory_stream" ],
    [ "CMenuItem", "class_v_s_t_g_u_i_1_1_c_menu_item.html", "class_v_s_t_g_u_i_1_1_c_menu_item" ],
    [ "CMouseWheelEditingSupport", "class_v_s_t_g_u_i_1_1_c_mouse_wheel_editing_support.html", "class_v_s_t_g_u_i_1_1_c_mouse_wheel_editing_support" ],
    [ "CMovieBitmap", "class_v_s_t_g_u_i_1_1_c_movie_bitmap.html", "class_v_s_t_g_u_i_1_1_c_movie_bitmap" ],
    [ "CMovieButton", "class_v_s_t_g_u_i_1_1_c_movie_button.html", "class_v_s_t_g_u_i_1_1_c_movie_button" ],
    [ "CMultiFrameBitmap", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap.html", "class_v_s_t_g_u_i_1_1_c_multi_frame_bitmap" ],
    [ "CMultiFrameBitmapDescription", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description.html", "struct_v_s_t_g_u_i_1_1_c_multi_frame_bitmap_description" ],
    [ "CMultiLineTextLabel", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label.html", "class_v_s_t_g_u_i_1_1_c_multi_line_text_label" ],
    [ "CNewFileSelector", "class_v_s_t_g_u_i_1_1_c_new_file_selector.html", "class_v_s_t_g_u_i_1_1_c_new_file_selector" ],
    [ "CNinePartTiledBitmap", "class_v_s_t_g_u_i_1_1_c_nine_part_tiled_bitmap.html", "class_v_s_t_g_u_i_1_1_c_nine_part_tiled_bitmap" ],
    [ "CNinePartTiledDescription", "struct_v_s_t_g_u_i_1_1_c_nine_part_tiled_description.html", "struct_v_s_t_g_u_i_1_1_c_nine_part_tiled_description" ],
    [ "COffscreenContext", "class_v_s_t_g_u_i_1_1_c_offscreen_context.html", "class_v_s_t_g_u_i_1_1_c_offscreen_context" ],
    [ "CommandMenuItemTargetAdapter", "class_v_s_t_g_u_i_1_1_command_menu_item_target_adapter.html", "class_v_s_t_g_u_i_1_1_command_menu_item_target_adapter" ],
    [ "CompressedUIDescription", "class_v_s_t_g_u_i_1_1_compressed_u_i_description.html", "class_v_s_t_g_u_i_1_1_compressed_u_i_description" ],
    [ "ConcatClip", "struct_v_s_t_g_u_i_1_1_concat_clip.html", "struct_v_s_t_g_u_i_1_1_concat_clip" ],
    [ "COnOffButton", "class_v_s_t_g_u_i_1_1_c_on_off_button.html", "class_v_s_t_g_u_i_1_1_c_on_off_button" ],
    [ "COpenGLView", "class_v_s_t_g_u_i_1_1_c_open_g_l_view.html", "class_v_s_t_g_u_i_1_1_c_open_g_l_view" ],
    [ "COptionMenu", "class_v_s_t_g_u_i_1_1_c_option_menu.html", "class_v_s_t_g_u_i_1_1_c_option_menu" ],
    [ "CParamDisplay", "class_v_s_t_g_u_i_1_1_c_param_display.html", "class_v_s_t_g_u_i_1_1_c_param_display" ],
    [ "CPoint", "struct_v_s_t_g_u_i_1_1_c_point.html", "struct_v_s_t_g_u_i_1_1_c_point" ],
    [ "CRect", "struct_v_s_t_g_u_i_1_1_c_rect.html", "struct_v_s_t_g_u_i_1_1_c_rect" ],
    [ "CResourceDescription", "class_v_s_t_g_u_i_1_1_c_resource_description.html", "class_v_s_t_g_u_i_1_1_c_resource_description" ],
    [ "CResourceInputStream", "class_v_s_t_g_u_i_1_1_c_resource_input_stream.html", "class_v_s_t_g_u_i_1_1_c_resource_input_stream" ],
    [ "CRockerSwitch", "class_v_s_t_g_u_i_1_1_c_rocker_switch.html", "class_v_s_t_g_u_i_1_1_c_rocker_switch" ],
    [ "CRowColumnView", "class_v_s_t_g_u_i_1_1_c_row_column_view.html", "class_v_s_t_g_u_i_1_1_c_row_column_view" ],
    [ "CScrollbar", "class_v_s_t_g_u_i_1_1_c_scrollbar.html", "class_v_s_t_g_u_i_1_1_c_scrollbar" ],
    [ "CScrollView", "class_v_s_t_g_u_i_1_1_c_scroll_view.html", "class_v_s_t_g_u_i_1_1_c_scroll_view" ],
    [ "CSearchTextEdit", "class_v_s_t_g_u_i_1_1_c_search_text_edit.html", "class_v_s_t_g_u_i_1_1_c_search_text_edit" ],
    [ "CSegmentButton", "class_v_s_t_g_u_i_1_1_c_segment_button.html", "class_v_s_t_g_u_i_1_1_c_segment_button" ],
    [ "CShadowViewContainer", "class_v_s_t_g_u_i_1_1_c_shadow_view_container.html", "class_v_s_t_g_u_i_1_1_c_shadow_view_container" ],
    [ "CSlider", "class_v_s_t_g_u_i_1_1_c_slider.html", "class_v_s_t_g_u_i_1_1_c_slider" ],
    [ "CSliderBase", "class_v_s_t_g_u_i_1_1_c_slider_base.html", "class_v_s_t_g_u_i_1_1_c_slider_base" ],
    [ "CSpecialDigit", "class_v_s_t_g_u_i_1_1_c_special_digit.html", "class_v_s_t_g_u_i_1_1_c_special_digit" ],
    [ "CSplashScreen", "class_v_s_t_g_u_i_1_1_c_splash_screen.html", "class_v_s_t_g_u_i_1_1_c_splash_screen" ],
    [ "CSplitView", "class_v_s_t_g_u_i_1_1_c_split_view.html", "class_v_s_t_g_u_i_1_1_c_split_view" ],
    [ "CSwitchBase", "class_v_s_t_g_u_i_1_1_c_switch_base.html", "class_v_s_t_g_u_i_1_1_c_switch_base" ],
    [ "CTabView", "class_v_s_t_g_u_i_1_1_c_tab_view.html", "class_v_s_t_g_u_i_1_1_c_tab_view" ],
    [ "CTextButton", "class_v_s_t_g_u_i_1_1_c_text_button.html", "class_v_s_t_g_u_i_1_1_c_text_button" ],
    [ "CTextEdit", "class_v_s_t_g_u_i_1_1_c_text_edit.html", "class_v_s_t_g_u_i_1_1_c_text_edit" ],
    [ "CTextLabel", "class_v_s_t_g_u_i_1_1_c_text_label.html", "class_v_s_t_g_u_i_1_1_c_text_label" ],
    [ "CTooltipSupport", "class_v_s_t_g_u_i_1_1_c_tooltip_support.html", "class_v_s_t_g_u_i_1_1_c_tooltip_support" ],
    [ "CVerticalSlider", "class_v_s_t_g_u_i_1_1_c_vertical_slider.html", "class_v_s_t_g_u_i_1_1_c_vertical_slider" ],
    [ "CVerticalSwitch", "class_v_s_t_g_u_i_1_1_c_vertical_switch.html", "class_v_s_t_g_u_i_1_1_c_vertical_switch" ],
    [ "CView", "class_v_s_t_g_u_i_1_1_c_view.html", "class_v_s_t_g_u_i_1_1_c_view" ],
    [ "CViewContainer", "class_v_s_t_g_u_i_1_1_c_view_container.html", "class_v_s_t_g_u_i_1_1_c_view_container" ],
    [ "CViewContainerDropTarget", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target.html", "struct_v_s_t_g_u_i_1_1_c_view_container_drop_target" ],
    [ "CVSTGUITimer", "class_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer.html", "class_v_s_t_g_u_i_1_1_c_v_s_t_g_u_i_timer" ],
    [ "CVuMeter", "class_v_s_t_g_u_i_1_1_c_vu_meter.html", "class_v_s_t_g_u_i_1_1_c_vu_meter" ],
    [ "CXYPad", "class_v_s_t_g_u_i_1_1_c_x_y_pad.html", "class_v_s_t_g_u_i_1_1_c_x_y_pad" ],
    [ "DataBrowserDelegateAdapter", "class_v_s_t_g_u_i_1_1_data_browser_delegate_adapter.html", "class_v_s_t_g_u_i_1_1_data_browser_delegate_adapter" ],
    [ "DataPackageIterator", "struct_v_s_t_g_u_i_1_1_data_package_iterator.html", "struct_v_s_t_g_u_i_1_1_data_package_iterator" ],
    [ "DelegationController", "class_v_s_t_g_u_i_1_1_delegation_controller.html", "class_v_s_t_g_u_i_1_1_delegation_controller" ],
    [ "DispatchList", "class_v_s_t_g_u_i_1_1_dispatch_list.html", "class_v_s_t_g_u_i_1_1_dispatch_list" ],
    [ "DragCallbackAdapter", "class_v_s_t_g_u_i_1_1_drag_callback_adapter.html", "class_v_s_t_g_u_i_1_1_drag_callback_adapter" ],
    [ "DragCallbackFunctions", "class_v_s_t_g_u_i_1_1_drag_callback_functions.html", "class_v_s_t_g_u_i_1_1_drag_callback_functions" ],
    [ "DragDescription", "struct_v_s_t_g_u_i_1_1_drag_description.html", "struct_v_s_t_g_u_i_1_1_drag_description" ],
    [ "DragEventData", "struct_v_s_t_g_u_i_1_1_drag_event_data.html", "struct_v_s_t_g_u_i_1_1_drag_event_data" ],
    [ "DragStartMouseObserver", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer.html", "struct_v_s_t_g_u_i_1_1_drag_start_mouse_observer" ],
    [ "DropTargetAdapter", "class_v_s_t_g_u_i_1_1_drop_target_adapter.html", "class_v_s_t_g_u_i_1_1_drop_target_adapter" ],
    [ "ERect", "struct_v_s_t_g_u_i_1_1_e_rect.html", "struct_v_s_t_g_u_i_1_1_e_rect" ],
    [ "Event", "struct_v_s_t_g_u_i_1_1_event.html", "struct_v_s_t_g_u_i_1_1_event" ],
    [ "EventConsumeState", "struct_v_s_t_g_u_i_1_1_event_consume_state.html", "struct_v_s_t_g_u_i_1_1_event_consume_state" ],
    [ "FinalAction", "class_v_s_t_g_u_i_1_1_final_action.html", "class_v_s_t_g_u_i_1_1_final_action" ],
    [ "FocusDrawingSettings", "struct_v_s_t_g_u_i_1_1_focus_drawing_settings.html", "struct_v_s_t_g_u_i_1_1_focus_drawing_settings" ],
    [ "GenericStringListDataBrowserSource", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source.html", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source" ],
    [ "GenericStringListDataBrowserSourceSelectionChanged", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source_selection_changed.html", "class_v_s_t_g_u_i_1_1_generic_string_list_data_browser_source_selection_changed" ],
    [ "GestureEvent", "struct_v_s_t_g_u_i_1_1_gesture_event.html", "struct_v_s_t_g_u_i_1_1_gesture_event" ],
    [ "GetViewOptions", "struct_v_s_t_g_u_i_1_1_get_view_options.html", "struct_v_s_t_g_u_i_1_1_get_view_options" ],
    [ "GlobalFonts", "struct_v_s_t_g_u_i_1_1_global_fonts.html", "struct_v_s_t_g_u_i_1_1_global_fonts" ],
    [ "GroupController", "class_v_s_t_g_u_i_1_1_group_controller.html", "class_v_s_t_g_u_i_1_1_group_controller" ],
    [ "IBitmapCreator", "class_v_s_t_g_u_i_1_1_i_bitmap_creator.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator" ],
    [ "IBitmapCreator2", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2.html", "class_v_s_t_g_u_i_1_1_i_bitmap_creator2" ],
    [ "IColorChooserDelegate", "class_v_s_t_g_u_i_1_1_i_color_chooser_delegate.html", "class_v_s_t_g_u_i_1_1_i_color_chooser_delegate" ],
    [ "ICommandMenuItemTarget", "class_v_s_t_g_u_i_1_1_i_command_menu_item_target.html", "class_v_s_t_g_u_i_1_1_i_command_menu_item_target" ],
    [ "IContentProvider", "class_v_s_t_g_u_i_1_1_i_content_provider.html", "class_v_s_t_g_u_i_1_1_i_content_provider" ],
    [ "IContextMenuController", "class_v_s_t_g_u_i_1_1_i_context_menu_controller.html", "class_v_s_t_g_u_i_1_1_i_context_menu_controller" ],
    [ "IContextMenuController2", "class_v_s_t_g_u_i_1_1_i_context_menu_controller2.html", "class_v_s_t_g_u_i_1_1_i_context_menu_controller2" ],
    [ "IController", "class_v_s_t_g_u_i_1_1_i_controller.html", "class_v_s_t_g_u_i_1_1_i_controller" ],
    [ "IControlListener", "class_v_s_t_g_u_i_1_1_i_control_listener.html", "class_v_s_t_g_u_i_1_1_i_control_listener" ],
    [ "IDataBrowserDelegate", "class_v_s_t_g_u_i_1_1_i_data_browser_delegate.html", "class_v_s_t_g_u_i_1_1_i_data_browser_delegate" ],
    [ "IDataPackage", "class_v_s_t_g_u_i_1_1_i_data_package.html", "class_v_s_t_g_u_i_1_1_i_data_package" ],
    [ "IDependency", "class_v_s_t_g_u_i_1_1_i_dependency.html", "class_v_s_t_g_u_i_1_1_i_dependency" ],
    [ "IDragCallback", "class_v_s_t_g_u_i_1_1_i_drag_callback.html", "class_v_s_t_g_u_i_1_1_i_drag_callback" ],
    [ "IDraggingSession", "class_v_s_t_g_u_i_1_1_i_dragging_session.html", "class_v_s_t_g_u_i_1_1_i_dragging_session" ],
    [ "IDropTarget", "class_v_s_t_g_u_i_1_1_i_drop_target.html", "class_v_s_t_g_u_i_1_1_i_drop_target" ],
    [ "IFocusDrawing", "class_v_s_t_g_u_i_1_1_i_focus_drawing.html", "class_v_s_t_g_u_i_1_1_i_focus_drawing" ],
    [ "IFocusViewObserver", "class_v_s_t_g_u_i_1_1_i_focus_view_observer.html", "class_v_s_t_g_u_i_1_1_i_focus_view_observer" ],
    [ "IFontChooserDelegate", "class_v_s_t_g_u_i_1_1_i_font_chooser_delegate.html", "class_v_s_t_g_u_i_1_1_i_font_chooser_delegate" ],
    [ "IKeyboardHook", "class_v_s_t_g_u_i_1_1_i_keyboard_hook.html", "class_v_s_t_g_u_i_1_1_i_keyboard_hook" ],
    [ "IListControlConfigurator", "class_v_s_t_g_u_i_1_1_i_list_control_configurator.html", "class_v_s_t_g_u_i_1_1_i_list_control_configurator" ],
    [ "IListControlDrawer", "class_v_s_t_g_u_i_1_1_i_list_control_drawer.html", "class_v_s_t_g_u_i_1_1_i_list_control_drawer" ],
    [ "IMouseObserver", "class_v_s_t_g_u_i_1_1_i_mouse_observer.html", "class_v_s_t_g_u_i_1_1_i_mouse_observer" ],
    [ "IMultiBitmapControl", "class_v_s_t_g_u_i_1_1_i_multi_bitmap_control.html", "class_v_s_t_g_u_i_1_1_i_multi_bitmap_control" ],
    [ "InputStream", "class_v_s_t_g_u_i_1_1_input_stream.html", "class_v_s_t_g_u_i_1_1_input_stream" ],
    [ "InputStreamContentProvider", "class_v_s_t_g_u_i_1_1_input_stream_content_provider.html", "class_v_s_t_g_u_i_1_1_input_stream_content_provider" ],
    [ "Interface", "class_v_s_t_g_u_i_1_1_interface.html", "class_v_s_t_g_u_i_1_1_interface" ],
    [ "IOptionMenuListener", "class_v_s_t_g_u_i_1_1_i_option_menu_listener.html", "class_v_s_t_g_u_i_1_1_i_option_menu_listener" ],
    [ "IReference", "class_v_s_t_g_u_i_1_1_i_reference.html", "class_v_s_t_g_u_i_1_1_i_reference" ],
    [ "IScaleFactorChangedListener", "class_v_s_t_g_u_i_1_1_i_scale_factor_changed_listener.html", "class_v_s_t_g_u_i_1_1_i_scale_factor_changed_listener" ],
    [ "IScrollbarDrawer", "class_v_s_t_g_u_i_1_1_i_scrollbar_drawer.html", "class_v_s_t_g_u_i_1_1_i_scrollbar_drawer" ],
    [ "ISplitViewController", "class_v_s_t_g_u_i_1_1_i_split_view_controller.html", "class_v_s_t_g_u_i_1_1_i_split_view_controller" ],
    [ "ISplitViewSeparatorDrawer", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer.html", "class_v_s_t_g_u_i_1_1_i_split_view_separator_drawer" ],
    [ "ITextEditListener", "class_v_s_t_g_u_i_1_1_i_text_edit_listener.html", "class_v_s_t_g_u_i_1_1_i_text_edit_listener" ],
    [ "ITextLabelListener", "class_v_s_t_g_u_i_1_1_i_text_label_listener.html", "class_v_s_t_g_u_i_1_1_i_text_label_listener" ],
    [ "IUIDescription", "class_v_s_t_g_u_i_1_1_i_u_i_description.html", "class_v_s_t_g_u_i_1_1_i_u_i_description" ],
    [ "IViewAddedRemovedObserver", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer.html", "class_v_s_t_g_u_i_1_1_i_view_added_removed_observer" ],
    [ "IViewContainerListener", "class_v_s_t_g_u_i_1_1_i_view_container_listener.html", "class_v_s_t_g_u_i_1_1_i_view_container_listener" ],
    [ "IViewCreator", "class_v_s_t_g_u_i_1_1_i_view_creator.html", "class_v_s_t_g_u_i_1_1_i_view_creator" ],
    [ "IViewEventListener", "class_v_s_t_g_u_i_1_1_i_view_event_listener.html", "class_v_s_t_g_u_i_1_1_i_view_event_listener" ],
    [ "IViewFactory", "class_v_s_t_g_u_i_1_1_i_view_factory.html", "class_v_s_t_g_u_i_1_1_i_view_factory" ],
    [ "IViewListener", "class_v_s_t_g_u_i_1_1_i_view_listener.html", "class_v_s_t_g_u_i_1_1_i_view_listener" ],
    [ "IViewMouseListener", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener.html", "class_v_s_t_g_u_i_1_1_i_view_mouse_listener" ],
    [ "IViewSwitchController", "class_v_s_t_g_u_i_1_1_i_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_i_view_switch_controller" ],
    [ "IVST3EditorDelegate", "class_v_s_t_g_u_i_1_1_i_v_s_t3_editor_delegate.html", "class_v_s_t_g_u_i_1_1_i_v_s_t3_editor_delegate" ],
    [ "KeyboardEvent", "struct_v_s_t_g_u_i_1_1_keyboard_event.html", "struct_v_s_t_g_u_i_1_1_keyboard_event" ],
    [ "ListenerProvider", "struct_v_s_t_g_u_i_1_1_listener_provider.html", "struct_v_s_t_g_u_i_1_1_listener_provider" ],
    [ "MallocAllocator", "struct_v_s_t_g_u_i_1_1_malloc_allocator.html", "struct_v_s_t_g_u_i_1_1_malloc_allocator" ],
    [ "MemoryContentProvider", "class_v_s_t_g_u_i_1_1_memory_content_provider.html", "class_v_s_t_g_u_i_1_1_memory_content_provider" ],
    [ "ModalViewSession", "struct_v_s_t_g_u_i_1_1_modal_view_session.html", "struct_v_s_t_g_u_i_1_1_modal_view_session" ],
    [ "ModifierEvent", "struct_v_s_t_g_u_i_1_1_modifier_event.html", "struct_v_s_t_g_u_i_1_1_modifier_event" ],
    [ "Modifiers", "struct_v_s_t_g_u_i_1_1_modifiers.html", "struct_v_s_t_g_u_i_1_1_modifiers" ],
    [ "MouseCancelEvent", "struct_v_s_t_g_u_i_1_1_mouse_cancel_event.html", "struct_v_s_t_g_u_i_1_1_mouse_cancel_event" ],
    [ "MouseDownEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_event.html", "struct_v_s_t_g_u_i_1_1_mouse_down_event" ],
    [ "MouseDownUpMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event.html", "struct_v_s_t_g_u_i_1_1_mouse_down_up_move_event" ],
    [ "MouseEnterEvent", "struct_v_s_t_g_u_i_1_1_mouse_enter_event.html", "struct_v_s_t_g_u_i_1_1_mouse_enter_event" ],
    [ "MouseEvent", "struct_v_s_t_g_u_i_1_1_mouse_event.html", "struct_v_s_t_g_u_i_1_1_mouse_event" ],
    [ "MouseEventButtonState", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state.html", "struct_v_s_t_g_u_i_1_1_mouse_event_button_state" ],
    [ "MouseExitEvent", "struct_v_s_t_g_u_i_1_1_mouse_exit_event.html", "struct_v_s_t_g_u_i_1_1_mouse_exit_event" ],
    [ "MouseMoveEvent", "struct_v_s_t_g_u_i_1_1_mouse_move_event.html", "struct_v_s_t_g_u_i_1_1_mouse_move_event" ],
    [ "MousePositionEvent", "struct_v_s_t_g_u_i_1_1_mouse_position_event.html", "struct_v_s_t_g_u_i_1_1_mouse_position_event" ],
    [ "MouseUpEvent", "struct_v_s_t_g_u_i_1_1_mouse_up_event.html", "struct_v_s_t_g_u_i_1_1_mouse_up_event" ],
    [ "MouseWheelEvent", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event.html", "struct_v_s_t_g_u_i_1_1_mouse_wheel_event" ],
    [ "MultiFrameBitmapView", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view.html", "class_v_s_t_g_u_i_1_1_multi_frame_bitmap_view" ],
    [ "OldKeyboardHookAdapter", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter.html", "class_v_s_t_g_u_i_1_1_old_keyboard_hook_adapter" ],
    [ "OldMouseObserverAdapter", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter.html", "class_v_s_t_g_u_i_1_1_old_mouse_observer_adapter" ],
    [ "Optional", "struct_v_s_t_g_u_i_1_1_optional.html", "struct_v_s_t_g_u_i_1_1_optional" ],
    [ "OptionMenuListenerAdapter", "class_v_s_t_g_u_i_1_1_option_menu_listener_adapter.html", "class_v_s_t_g_u_i_1_1_option_menu_listener_adapter" ],
    [ "OutputStream", "class_v_s_t_g_u_i_1_1_output_stream.html", "class_v_s_t_g_u_i_1_1_output_stream" ],
    [ "OwningPointer", "class_v_s_t_g_u_i_1_1_owning_pointer.html", "class_v_s_t_g_u_i_1_1_owning_pointer" ],
    [ "PadController", "class_v_s_t_g_u_i_1_1_pad_controller.html", "class_v_s_t_g_u_i_1_1_pad_controller" ],
    [ "ParameterChangeListener", "class_v_s_t_g_u_i_1_1_parameter_change_listener.html", "class_v_s_t_g_u_i_1_1_parameter_change_listener" ],
    [ "PluginGUIEditor", "class_v_s_t_g_u_i_1_1_plugin_g_u_i_editor.html", "class_v_s_t_g_u_i_1_1_plugin_g_u_i_editor" ],
    [ "ReferenceCounted", "class_v_s_t_g_u_i_1_1_reference_counted.html", "class_v_s_t_g_u_i_1_1_reference_counted" ],
    [ "SeekableStream", "class_v_s_t_g_u_i_1_1_seekable_stream.html", "class_v_s_t_g_u_i_1_1_seekable_stream" ],
    [ "SharedPointer", "class_v_s_t_g_u_i_1_1_shared_pointer.html", "class_v_s_t_g_u_i_1_1_shared_pointer" ],
    [ "StaticListControlConfigurator", "class_v_s_t_g_u_i_1_1_static_list_control_configurator.html", "class_v_s_t_g_u_i_1_1_static_list_control_configurator" ],
    [ "StdOutStream", "class_v_s_t_g_u_i_1_1_std_out_stream.html", "class_v_s_t_g_u_i_1_1_std_out_stream" ],
    [ "StringListControlDrawer", "class_v_s_t_g_u_i_1_1_string_list_control_drawer.html", "class_v_s_t_g_u_i_1_1_string_list_control_drawer" ],
    [ "TextEditListenerAdapter", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_edit_listener_adapter" ],
    [ "TextLabelListenerAdapter", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter.html", "class_v_s_t_g_u_i_1_1_text_label_listener_adapter" ],
    [ "TrimOptions", "struct_v_s_t_g_u_i_1_1_trim_options.html", "struct_v_s_t_g_u_i_1_1_trim_options" ],
    [ "UIAttributes", "class_v_s_t_g_u_i_1_1_u_i_attributes.html", "class_v_s_t_g_u_i_1_1_u_i_attributes" ],
    [ "UIDescription", "class_v_s_t_g_u_i_1_1_u_i_description.html", "class_v_s_t_g_u_i_1_1_u_i_description" ],
    [ "UIDescriptionListener", "class_v_s_t_g_u_i_1_1_u_i_description_listener.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener" ],
    [ "UIDescriptionListenerAdapter", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter.html", "class_v_s_t_g_u_i_1_1_u_i_description_listener_adapter" ],
    [ "UIDescriptionListenerOff", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off.html", "struct_v_s_t_g_u_i_1_1_u_i_description_listener_off" ],
    [ "UIDescriptionViewSwitchController", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller.html", "class_v_s_t_g_u_i_1_1_u_i_description_view_switch_controller" ],
    [ "UIViewFactory", "class_v_s_t_g_u_i_1_1_u_i_view_factory.html", "class_v_s_t_g_u_i_1_1_u_i_view_factory" ],
    [ "UIViewSwitchContainer", "class_v_s_t_g_u_i_1_1_u_i_view_switch_container.html", "class_v_s_t_g_u_i_1_1_u_i_view_switch_container" ],
    [ "UTF8CharacterIterator", "class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator.html", "class_v_s_t_g_u_i_1_1_u_t_f8_character_iterator" ],
    [ "UTF8CodePointIterator", "class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator.html", "class_v_s_t_g_u_i_1_1_u_t_f8_code_point_iterator" ],
    [ "UTF8String", "class_v_s_t_g_u_i_1_1_u_t_f8_string.html", "class_v_s_t_g_u_i_1_1_u_t_f8_string" ],
    [ "UTF8StringView", "class_v_s_t_g_u_i_1_1_u_t_f8_string_view.html", "class_v_s_t_g_u_i_1_1_u_t_f8_string_view" ],
    [ "ViewContainerListenerAdapter", "class_v_s_t_g_u_i_1_1_view_container_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_container_listener_adapter" ],
    [ "ViewCreatorAdapter", "class_v_s_t_g_u_i_1_1_view_creator_adapter.html", "class_v_s_t_g_u_i_1_1_view_creator_adapter" ],
    [ "ViewCreatorRegistry", "class_v_s_t_g_u_i_1_1_view_creator_registry.html", "class_v_s_t_g_u_i_1_1_view_creator_registry" ],
    [ "ViewEventListenerAdapter", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_event_listener_adapter" ],
    [ "ViewListenerAdapter", "class_v_s_t_g_u_i_1_1_view_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_listener_adapter" ],
    [ "ViewMouseListenerAdapter", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter.html", "class_v_s_t_g_u_i_1_1_view_mouse_listener_adapter" ],
    [ "VST3Editor", "class_v_s_t_g_u_i_1_1_v_s_t3_editor.html", "class_v_s_t_g_u_i_1_1_v_s_t3_editor" ],
    [ "VST3EditorDelegate", "class_v_s_t_g_u_i_1_1_v_s_t3_editor_delegate.html", "class_v_s_t_g_u_i_1_1_v_s_t3_editor_delegate" ],
    [ "VSTGUIEditorInterface", "class_v_s_t_g_u_i_1_1_v_s_t_g_u_i_editor_interface.html", "class_v_s_t_g_u_i_1_1_v_s_t_g_u_i_editor_interface" ],
    [ "ZLibInputContentProvider", "class_v_s_t_g_u_i_1_1_z_lib_input_content_provider.html", "class_v_s_t_g_u_i_1_1_z_lib_input_content_provider" ],
    [ "ZLibInputStream", "class_v_s_t_g_u_i_1_1_z_lib_input_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_input_stream" ],
    [ "ZLibOutputStream", "class_v_s_t_g_u_i_1_1_z_lib_output_stream.html", "class_v_s_t_g_u_i_1_1_z_lib_output_stream" ],
    [ "ZoomGestureEvent", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event.html", "struct_v_s_t_g_u_i_1_1_zoom_gesture_event" ],
    [ "AssertionHandler", "namespace_v_s_t_g_u_i.html#ad12bfb972769bcb8fff46fb6bf190fb1", null ],
    [ "AtomicReferenceCounted", "namespace_v_s_t_g_u_i.html#adb65eb0fd1715f989f4680f576507ea7", null ],
    [ "CConstMenuItemIterator", "namespace_v_s_t_g_u_i.html#ac4c4a3f84ba1ad06cc2c6d897bbaa885", null ],
    [ "CCoord", "namespace_v_s_t_g_u_i.html#a6a872457eeeb5786083f968ca3fc0291", null ],
    [ "CFontRef", "namespace_v_s_t_g_u_i.html#a983d254a05cef7e1af39df9a3ba5cb31", null ],
    [ "CMenuItemIterator", "namespace_v_s_t_g_u_i.html#ac5d2d5ae2f6fa970821129ccaa21d2a8", null ],
    [ "CMenuItemList", "namespace_v_s_t_g_u_i.html#ae866b004d82d1e368dd3f5bc8386b2e1", null ],
    [ "CParamDisplayValueToStringProc", "namespace_v_s_t_g_u_i.html#a01e4013e5947137c376d11ba08e65e97", null ],
    [ "CTextEditStringToValueProc", "namespace_v_s_t_g_u_i.html#aeb8a18f8dd4b9f3824fff995ced2ecaf", null ],
    [ "CViewAttributeID", "namespace_v_s_t_g_u_i.html#ab344f8ed42cf4fb22917bae466fa6897", null ],
    [ "GradientColorStop", "namespace_v_s_t_g_u_i.html#afcc200df0a75d784f2b35340aae8e428", null ],
    [ "GradientColorStopMap", "namespace_v_s_t_g_u_i.html#a5a02df4a1c4750e808a69b45720207cb", null ],
    [ "IdStringPtr", "namespace_v_s_t_g_u_i.html#a21cc6afea0f23741f903db22fffdbe78", null ],
    [ "InterfacePtr", "namespace_v_s_t_g_u_i.html#a02527d23fb7254ee7a17e39a44c45fe6", null ],
    [ "LineList", "namespace_v_s_t_g_u_i.html#a79477873931d291da384eb2bfae90665", null ],
    [ "LinePair", "namespace_v_s_t_g_u_i.html#abbf93dee2928345015a385246266b6de", null ],
    [ "ModalViewSessionID", "namespace_v_s_t_g_u_i.html#ac52277d36900fca1d62af8e941a091da", null ],
    [ "NonAtomicReferenceCounted", "namespace_v_s_t_g_u_i.html#a9a2849d4b8c248f06a53ac5a4785a9a1", null ],
    [ "PlatformBitmapPtr", "namespace_v_s_t_g_u_i.html#a692bace48e9a5a04714ca968839c043c", null ],
    [ "PlatformFactoryPtr", "namespace_v_s_t_g_u_i.html#ab4cfddd3a2ddff746b2e37ca2eda4218", null ],
    [ "PlatformFileSelectorPtr", "namespace_v_s_t_g_u_i.html#a5959ebce637f14f6daabea82c525177c", null ],
    [ "PlatformFontPtr", "namespace_v_s_t_g_u_i.html#a92a65435a53ecdc78fe79c313978b5e2", null ],
    [ "PlatformFramePtr", "namespace_v_s_t_g_u_i.html#a6a658c6ce8d779da1cfdb30f9a91bbf8", null ],
    [ "PlatformGradientPtr", "namespace_v_s_t_g_u_i.html#a553287139d7b3c2d72206ec69e88c2c3", null ],
    [ "PlatformGraphicsDeviceContextPtr", "namespace_v_s_t_g_u_i.html#a31bc5c657a17f12e9880ff136897bd2a", null ],
    [ "PlatformGraphicsDevicePtr", "namespace_v_s_t_g_u_i.html#a28dd00c729d1192f745167c436f2830c", null ],
    [ "PlatformGraphicsPathFactoryPtr", "namespace_v_s_t_g_u_i.html#af82f9ccca9009dec7a3dd4f34b25dc7b", null ],
    [ "PlatformGraphicsPathPtr", "namespace_v_s_t_g_u_i.html#a4933a6a3e88daad1eb3223a128bc5b57", null ],
    [ "PlatformResourceInputStreamPtr", "namespace_v_s_t_g_u_i.html#a975ab25ec941cb6345d5612800e0f3ea", null ],
    [ "PlatformStringPtr", "namespace_v_s_t_g_u_i.html#a2f58f3095b6d0389db494ea401afef22", null ],
    [ "PlatformTimerPtr", "namespace_v_s_t_g_u_i.html#a24528a069c61df796b973b9f9149fbca", null ],
    [ "PointList", "namespace_v_s_t_g_u_i.html#ad2fc415eb172cbcccde2459300aae5af", null ],
    [ "ReverseViewIterator", "namespace_v_s_t_g_u_i.html#a0d390ba7909d00d28aeebca3da0e5086", null ],
    [ "UIAttributesMap", "namespace_v_s_t_g_u_i.html#ac083384b91d26fbf6d5751ce7216f54d", null ],
    [ "UTF8StringBuffer", "namespace_v_s_t_g_u_i.html#a0e830c33227280573a9a72c7ef16eaf4", null ],
    [ "UTF8StringPtr", "namespace_v_s_t_g_u_i.html#a3fd19826d804be46b46005b0410f3e48", null ],
    [ "ViewCreatorRegistryMap", "namespace_v_s_t_g_u_i.html#acbddc1977524c692f346bd9cfa438e7a", null ],
    [ "ViewIterator", "namespace_v_s_t_g_u_i.html#abfc3fff23be453a6941838ec7937f671", null ],
    [ "BitmapInterpolationQuality", "namespace_v_s_t_g_u_i.html#a9d48f1a04e75a1996632b1995fbe7aaf", [
      [ "kDefault", "namespace_v_s_t_g_u_i.html#a9d48f1a04e75a1996632b1995fbe7aafa6867faeaa475fda467e48267db2bb8a8", null ],
      [ "kLow", "namespace_v_s_t_g_u_i.html#a9d48f1a04e75a1996632b1995fbe7aafacd8fe42741a3bbc973bbf1d404afeff4", null ],
      [ "kMedium", "namespace_v_s_t_g_u_i.html#a9d48f1a04e75a1996632b1995fbe7aafa3ce9d817402b59f65fb01ea044bb1ee9", null ],
      [ "kHigh", "namespace_v_s_t_g_u_i.html#a9d48f1a04e75a1996632b1995fbe7aafaa022f15e910eb36278094efb6e808a07", null ]
    ] ],
    [ "ByteOrder", "namespace_v_s_t_g_u_i.html#aaeb92d42f5a6e27b8ba19f18d69d142b", [
      [ "kBigEndianByteOrder", "namespace_v_s_t_g_u_i.html#aaeb92d42f5a6e27b8ba19f18d69d142ba15148593d2dfd8512a49b095d041086d", null ],
      [ "kLittleEndianByteOrder", "namespace_v_s_t_g_u_i.html#aaeb92d42f5a6e27b8ba19f18d69d142badcfecc9268d7939d7df58a68c45e6982", null ],
      [ "kNativeByteOrder", "namespace_v_s_t_g_u_i.html#aaeb92d42f5a6e27b8ba19f18d69d142ba2a315cd28881586a1e196b8eb3cb312d", null ]
    ] ],
    [ "CButton", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4f", [
      [ "kLButton", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa0615236debd9aeb2cc7cea760d7b59ac", null ],
      [ "kMButton", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa1446fcb433914cafe7cb2eacbfec30bd", null ],
      [ "kRButton", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa401c45cfb0132b0667ed3ec483a42a8c", null ],
      [ "kShift", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa5d98ebe7d25e63d2d73a1458550d8268", null ],
      [ "kControl", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa559deb9820ca250d1e27a9a18f51ea07", null ],
      [ "kAlt", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa5e3c111261bf020bf40cf5f4e899db1c", null ],
      [ "kApple", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa0e03045965f584eb88dc85dbe36745a7", null ],
      [ "kButton4", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa046abdc7439e88066a0b142db24253bb", null ],
      [ "kButton5", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa73909c4c3ad0f71e0efccbd6e027bdf8", null ],
      [ "kDoubleClick", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa44b7329ca865fc01c466a3caf5f94dc1", null ],
      [ "kMouseWheelInverted", "namespace_v_s_t_g_u_i.html#af163f328732e5bf4fff32a0af33cfb4fa2ad6905f4d4c15aae7302cf4233d1dfc", null ]
    ] ],
    [ "CCursorType", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609", [
      [ "kCursorDefault", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a40a411aefb0b65462313e42d8ade4e1b", null ],
      [ "kCursorWait", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a5d4286aeed89750335e627712ffd8964", null ],
      [ "kCursorHSize", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609ab5e5e56db0db2a830d933d46f86222b0", null ],
      [ "kCursorVSize", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a0e030a3a209daefb3631285d921f4c2d", null ],
      [ "kCursorSizeAll", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a90afec674a440585749380256bfd7270", null ],
      [ "kCursorNESWSize", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609ada5b707f35f6badcc46cd459b3e48d1e", null ],
      [ "kCursorNWSESize", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a44c3e21f1e30b19e4d6a4565c338ef32", null ],
      [ "kCursorCopy", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a0bd223915d667d13a3c8d93bf4cb968d", null ],
      [ "kCursorNotAllowed", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a317132e98927cafa870bc56157b21693", null ],
      [ "kCursorPointingHand", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609aeec2f8063a0e62852334010a0549c8e4", null ],
      [ "kCursorIBeam", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a5db586fd9be4aabbd25dbbd8b3735053", null ],
      [ "kCursorCrosshair", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609aee923eaa4954aa9d385c5f55a9f01a67", null ],
      [ "kCursorMovableObject", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609ab3c3440a432ba36c51d19df2d462db03", null ],
      [ "kCursorMoveObject", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a8b0b5f0e18dfaf7a7eb6922874a2df9d", null ],
      [ "kCursorHand", "namespace_v_s_t_g_u_i.html#a1abab90c69fe188695d974d72708f609a1ca05d526408fe0343c2aff9549b86be", null ]
    ] ],
    [ "CDrawModeFlags", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5", [
      [ "kAliasing", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5a8f70930a006665848ee20c6e23792a26", null ],
      [ "kAntiAliasing", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5aafe2e2c0bbb8da0d1e70a0ab0b4b5576", null ],
      [ "kNonIntegralMode", "namespace_v_s_t_g_u_i.html#a370d84d9d1737b1b4540a081630719a5af25224203477972dabc839fb6ed2c575", null ]
    ] ],
    [ "CDrawStyle", "namespace_v_s_t_g_u_i.html#ab2846c8d9448af4748442683624274e3", [
      [ "kDrawStroked", "namespace_v_s_t_g_u_i.html#ab2846c8d9448af4748442683624274e3a35c203c97f22a35150bd470622562c87", null ],
      [ "kDrawFilled", "namespace_v_s_t_g_u_i.html#ab2846c8d9448af4748442683624274e3a52df0036e9632981308681f0d89c9542", null ],
      [ "kDrawFilledAndStroked", "namespace_v_s_t_g_u_i.html#ab2846c8d9448af4748442683624274e3a0b8b6be31f16a6009bc40a5cfaac2353", null ]
    ] ],
    [ "CHoriTxtAlign", "namespace_v_s_t_g_u_i.html#a6a7261519a64713ba0c8ec1d82dde2b9", [
      [ "kLeftText", "namespace_v_s_t_g_u_i.html#a6a7261519a64713ba0c8ec1d82dde2b9aee7755d3cfee1d837c32f3189b44d51d", null ],
      [ "kCenterText", "namespace_v_s_t_g_u_i.html#a6a7261519a64713ba0c8ec1d82dde2b9aa73e45986ce07d29ba1375ce15a98b55", null ],
      [ "kRightText", "namespace_v_s_t_g_u_i.html#a6a7261519a64713ba0c8ec1d82dde2b9abf15e13de1023eb096bfe85d2f328fcf", null ]
    ] ],
    [ "CKnobMode", "namespace_v_s_t_g_u_i.html#a3abb1c1a5bc4c19464dea794f09cb773", [
      [ "kCircularMode", "namespace_v_s_t_g_u_i.html#a3abb1c1a5bc4c19464dea794f09cb773a261944b6b143c6fc78fa1e9c783200ea", null ],
      [ "kRelativCircularMode", "namespace_v_s_t_g_u_i.html#a3abb1c1a5bc4c19464dea794f09cb773a98a7d7b1f331414876a55df149340e1e", null ],
      [ "kLinearMode", "namespace_v_s_t_g_u_i.html#a3abb1c1a5bc4c19464dea794f09cb773a248b4aaa79db639d5610c6e632269d7a", null ]
    ] ],
    [ "CMessageResult", "namespace_v_s_t_g_u_i.html#a2c1cd94c80c1fa6feeb2d29e8116caa7", [
      [ "kMessageUnknown", "namespace_v_s_t_g_u_i.html#a2c1cd94c80c1fa6feeb2d29e8116caa7ad29b17573cf418d6c7f9b390d03df3a5", null ],
      [ "kMessageNotified", "namespace_v_s_t_g_u_i.html#a2c1cd94c80c1fa6feeb2d29e8116caa7a6567b0d040914dbae73162c92b369746", null ]
    ] ],
    [ "CMouseEventResult", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092", [
      [ "kMouseEventNotImplemented", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092a0b60edc7ce9850ff4aa55a8a237a6b77", null ],
      [ "kMouseEventHandled", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092a8bb1ee91a3b1b6baa050d9634f4abcc0", null ],
      [ "kMouseEventNotHandled", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092abc548486ea189b8cb22844fc8584c83b", null ],
      [ "kMouseDownEventHandledButDontNeedMovedOrUpEvents", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092a0073c201daa8eed4d3dc50b00dd4889e", null ],
      [ "kMouseMoveEventHandledButDontNeedMoreEvents", "namespace_v_s_t_g_u_i.html#ac49f4c9b44d5ce2870a1790690bc1092a4654328289f4b55e2c843877a0346ae5", null ]
    ] ],
    [ "CMouseWheelAxis", "namespace_v_s_t_g_u_i.html#af1c743b921a952411002bd6ead116259", [
      [ "kMouseWheelAxisX", "namespace_v_s_t_g_u_i.html#af1c743b921a952411002bd6ead116259aeceffa04215d79d528483e52be2fe04d", null ],
      [ "kMouseWheelAxisY", "namespace_v_s_t_g_u_i.html#af1c743b921a952411002bd6ead116259a6f16b7686900aa15fc985600a2d2398e", null ]
    ] ],
    [ "CSliderMode", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5a", [
      [ "Touch", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5aaf0f31c9700c6b10d8a20dc487b2ae6a8", null ],
      [ "RelativeTouch", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5aa5319f3d024c5007cf4350cb7fc4710ff", null ],
      [ "FreeClick", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5aaafe838776463686aa64c1a7554b75c67", null ],
      [ "Ramp", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5aa99b4c3afc6aaa3ab4de17c90455a55eb", null ],
      [ "UseGlobal", "namespace_v_s_t_g_u_i.html#a1018c1a42e0f81b7d19f64deec840c5aa32bc6f716b39c3030c2170fcae3f8810", null ]
    ] ],
    [ "CTxtFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153", [
      [ "kNormalFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153a70b41f3e517cb08776131df4e67d8d8a", null ],
      [ "kBoldFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153aca252585ab8fc18027f9e66dcfbfe275", null ],
      [ "kItalicFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153acb1f8a686a28a68ca16f25f4068a71b1", null ],
      [ "kUnderlineFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153af47c55f13ea1dd3e34b7662a21d19a3a", null ],
      [ "kStrikethroughFace", "namespace_v_s_t_g_u_i.html#a3dbcb42916cd947beb66b94f6941b153ab4386fa93764d0eb54c1a9f8e656bbcd", null ]
    ] ],
    [ "CViewAutosizing", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072", [
      [ "kAutosizeNone", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072a2f3d319ba44efb23cfe90f48524b2ead", null ],
      [ "kAutosizeLeft", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072af5b8e889ed5d6cb3bf667bab75db01bd", null ],
      [ "kAutosizeTop", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072affdf931de8c8f198d764cda0904c5ba9", null ],
      [ "kAutosizeRight", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072a059487b88e4923e7e69d06e9788d63f3", null ],
      [ "kAutosizeBottom", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072ac380fef54ce5601fe65549aacac18955", null ],
      [ "kAutosizeColumn", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072aa559ba8420aad39a16ab74eb44fa10b9", null ],
      [ "kAutosizeRow", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072ab0c5c2a1a494bb087a5869b7bba6a973", null ],
      [ "kAutosizeAll", "namespace_v_s_t_g_u_i.html#ae791692d48cb67ab011e9601124c5072a0999a30326135093d640c59d01bb7b6c", null ]
    ] ],
    [ "DragOperation", "group__new__in__4__7.html#ga3cbd589c354a1539328b774d6ec68779", [
      [ "Copy", "group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a5fb63579fc981698f97d55bfecb213ea", null ],
      [ "Move", "group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6bc362dbf494c61ea117fe3c71ca48a5", null ],
      [ "None", "group__new__in__4__7.html#gga3cbd589c354a1539328b774d6ec68779a6adf97f83acf6453d4a6a4b1070f3754", null ]
    ] ],
    [ "DragResult", "namespace_v_s_t_g_u_i.html#a043b7169b3544dbfc7de8df93cb3bc4c", [
      [ "kDragRefused", "namespace_v_s_t_g_u_i.html#a043b7169b3544dbfc7de8df93cb3bc4ca5188b57dcd1779dfdce44f142462a145", null ],
      [ "kDragMoved", "namespace_v_s_t_g_u_i.html#a043b7169b3544dbfc7de8df93cb3bc4ca14d7d825857601a986620924564da03b", null ],
      [ "kDragCopied", "namespace_v_s_t_g_u_i.html#a043b7169b3544dbfc7de8df93cb3bc4ca7c67ad4b08893b1853795a06ad771eb5", null ],
      [ "kDragError", "namespace_v_s_t_g_u_i.html#a043b7169b3544dbfc7de8df93cb3bc4ca117231182e9354612022f0742d7b762f", null ]
    ] ],
    [ "EventType", "group__new__in__4__11.html#ga95d9abac82e22b37b43c182b8af6704f", [
      [ "Unknown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa88183b946cc5f0e8c96b2e66e1c74a7e", null ],
      [ "MouseDown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fabf90db242043990aa80fde01f233665d", null ],
      [ "MouseMove", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fafd060c0c157323f1e43e0704d4f3ffc8", null ],
      [ "MouseUp", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa5c55840fe2a83a886590c780f0aa7031", null ],
      [ "MouseCancel", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704facc00c90abd23024acb572073009c2883", null ],
      [ "MouseEnter", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa68c02431dd2d34247118300cf24c77ea", null ],
      [ "MouseExit", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa0dc1a232157a515e987731d07267723e", null ],
      [ "MouseWheel", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa6924f81750ac471df87fed683bcea516", null ],
      [ "ZoomGesture", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa108a2de26b5b24d5e9d7c279599bab40", null ],
      [ "KeyUp", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704fa0f8baa14654b1f6ef00fed708c7f198a", null ],
      [ "KeyDown", "group__new__in__4__11.html#gga95d9abac82e22b37b43c182b8af6704facfd07bf1effd88bca04a12a087777354", null ]
    ] ],
    [ "ModifierKey", "group__new__in__4__11.html#ga51910458d0a923b29f1694654d8eb00a", [
      [ "Shift", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa825a3d98017bab11815ad2817201324c", null ],
      [ "Alt", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aaa2e92861b757ab878312dd57993d60cf", null ],
      [ "Control", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aaa1595abbb4c3a326636dd178757cd6c1", null ],
      [ "Super", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa0ce3266d4eb71ad50f7a90aee6d21dcd", null ],
      [ "None", "group__new__in__4__11.html#gga51910458d0a923b29f1694654d8eb00aa6adf97f83acf6453d4a6a4b1070f3754", null ]
    ] ],
    [ "MouseButton", "group__new__in__4__11.html#gab8d93bdfbb0fd7ae143bbfda46bf38bc", [
      [ "None", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca6adf97f83acf6453d4a6a4b1070f3754", null ],
      [ "Left", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca945d5e233cf7d6240f6b783b36a374ff", null ],
      [ "Middle", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bcab1ca34f82e83c52b010f86955f264e05", null ],
      [ "Right", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca92b09c7c48c520c3c55e497875da437c", null ],
      [ "Fourth", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca6e599f7a2a9186d391be4537f105be98", null ],
      [ "Fifth", "group__new__in__4__11.html#ggab8d93bdfbb0fd7ae143bbfda46bf38bca0abdfd715970bd0ef7d5574daa0e6d0b", null ]
    ] ],
    [ "SeekMode", "namespace_v_s_t_g_u_i.html#a84d76d32dd4ef90e5a90cf759b7e563f", [
      [ "Set", "namespace_v_s_t_g_u_i.html#a84d76d32dd4ef90e5a90cf759b7e563fa5d5b78699e57104f2fa03bbdf7b9197b", null ],
      [ "Current", "namespace_v_s_t_g_u_i.html#a84d76d32dd4ef90e5a90cf759b7e563fa222a267cc5778206b253be35ee3ddab5", null ],
      [ "End", "namespace_v_s_t_g_u_i.html#a84d76d32dd4ef90e5a90cf759b7e563fa87557f11575c0ad78e4e28abedc13b6e", null ]
    ] ],
    [ "VirtualKey", "group__new__in__4__11.html#ga85a6e0e5dacc5cf40c660ea540b6e9d6", [
      [ "None", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6adf97f83acf6453d4a6a4b1070f3754", null ],
      [ "Back", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0557fa923dcee4d0f86b1409f5c2167f", null ],
      [ "Tab", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a5c6ba25104401c9ee0650230fc6ba413", null ],
      [ "Clear", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6adc30bc0c7914db5918da4263fce93ad2", null ],
      [ "Return", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a988fd738de9c6d177440c5dcf69e73ce", null ],
      [ "Pause", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a105b296a83f9c105355403f3332af50f", null ],
      [ "Escape", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a013ec032d3460d4be4431c6ab1f8f224", null ],
      [ "Space", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ad511f8439ecde36647437fbba67a4394", null ],
      [ "Next", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a10ac3d04253ef7e1ddc73e6091c0cd55", null ],
      [ "End", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a87557f11575c0ad78e4e28abedc13b6e", null ],
      [ "Home", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a8cf04a9734132302f96da8e113e80ce5", null ],
      [ "Left", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a945d5e233cf7d6240f6b783b36a374ff", null ],
      [ "Up", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a258f49887ef8d14ac268c92b02503aaa", null ],
      [ "Right", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a92b09c7c48c520c3c55e497875da437c", null ],
      [ "Down", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a08a38277b0309070706f6652eeae9a53", null ],
      [ "PageUp", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a9b869c510c75c5827ac82e49d4340927", null ],
      [ "PageDown", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aee3677bcca83ece9384b01e43952bf33", null ],
      [ "Select", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae0626222614bdee31951d84c64e5e9ff", null ],
      [ "Print", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a13dba24862cf9128167a59100e154c8d", null ],
      [ "Enter", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6af1851d5600eae616ee802a31ac74701b", null ],
      [ "Snapshot", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ad4e2713d1b1725a1592f9268589f990d", null ],
      [ "Insert", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aa458be0f08b7e4ff3c0f633c100176c0", null ],
      [ "Delete", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6af2a6c498fb90ee345d997f888fce3b18", null ],
      [ "Help", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6a26f548831e6a8c26bfbbd9f6ec61e0", null ],
      [ "NumPad0", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6d3fe859ef4f9d1e8c2e75431c1b7146", null ],
      [ "NumPad1", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a2e6361ee3b8e634cb3b172838a86a351", null ],
      [ "NumPad2", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a63724eb8f83875a8d21dd82b1554a790", null ],
      [ "NumPad3", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aedbd16f7133f080a0c4e479dd55af10c", null ],
      [ "NumPad4", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a672c56a1e1c76b75f47f303823edbfe2", null ],
      [ "NumPad5", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a02a8a1ed101d8903b4b4ab108457716c", null ],
      [ "NumPad6", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a752338562556e765e3db045e17af884b", null ],
      [ "NumPad7", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a2c0344963ddd21bd2951b00664636094", null ],
      [ "NumPad8", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae409cf9af5cfc28aed6cf45ac0edf435", null ],
      [ "NumPad9", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6abec4386b816c0db1696a9906734d2df6", null ],
      [ "Multiply", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae257376d913f3b53cbb4a9b19d770648", null ],
      [ "Add", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6aec211f7c20af43e742bf2570c3cb84f9", null ],
      [ "Separator", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a04b2e4188d4ef8051e4699da8af01335", null ],
      [ "Subtract", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a1d9baf077ee87921f57a8fe42d510b65", null ],
      [ "Decimal", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a937504f318f04eaf0f1d701df4c4d7f3", null ],
      [ "Divide", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0b914e196182d02615487e9793ecff3d", null ],
      [ "F1", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae1dffc8709f31a4987c8a88334107e89", null ],
      [ "F2", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6afe5c3684dce76cdd9f7f42430868aa74", null ],
      [ "F3", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a4b6bf4b531770872d4328ce69bef5627", null ],
      [ "F4", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae7e0e72401a9f2718ed0f39f2861d702", null ],
      [ "F5", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a37f438df6a6d5ba4c17ef8ca58562f00", null ],
      [ "F6", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a1faf42f2823f184eb2c9f0dffe5d73f2", null ],
      [ "F7", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a47489eb597b7db34caa24b1fc78fc839", null ],
      [ "F8", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a4787509ad9f9d747a81a30e9dde3d4a7", null ],
      [ "F9", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a892a245e287c163080b23db737d3c4c9", null ],
      [ "F10", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ab213ce22ca6ad4eda8db82966b9b6e5a", null ],
      [ "F11", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a643b0662422d1d0dffa3fca2e2bf28a8", null ],
      [ "F12", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ae902674982fc99aa343cdd94da7476c3", null ],
      [ "NumLock", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6acf6cc0261135c6d163fd4305375773d2", null ],
      [ "Scroll", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a105078d294d30c978ca2badf7f376934", null ],
      [ "ShiftModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a5592f6f44f582301112b08ae0d9ae40f", null ],
      [ "ControlModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6ac9a56b66fc6e5d13261b02ad173b9664", null ],
      [ "AltModifier", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a6a29caa75381017a69d54f7467dfa3fd", null ],
      [ "Equals", "group__new__in__4__11.html#gga85a6e0e5dacc5cf40c660ea540b6e9d6a0ccb67e7eaae09d9e4078d161eeca100", null ]
    ] ],
    [ "asInterface", "namespace_v_s_t_g_u_i.html#ae441d9d401751310469b2ba75ef7fa77", null ],
    [ "asKeyboardEvent", "group__new__in__4__11.html#gad3ddface7353cedd60e63157ed90e9c8", null ],
    [ "asModifierEvent", "group__new__in__4__11.html#ga98ca899042462113b5b39f40433bcc03", null ],
    [ "asMouseDownEvent", "group__new__in__4__11.html#gade54ccee6e74309deb553fad5eace0f6", null ],
    [ "asMouseEvent", "group__new__in__4__11.html#ga95bbc88455eb2c9ef3d18f979f72db09", null ],
    [ "asMousePositionEvent", "group__new__in__4__11.html#gacb2a0b731eed6fb529ca5ade8b6add76", null ],
    [ "begin", "namespace_v_s_t_g_u_i.html#a08d856cad12896f58291f099d9732457", null ],
    [ "boxesForGauss", "namespace_v_s_t_g_u_i.html#abcf6a3f540d01f3a4df8db781b6f08cb", null ],
    [ "buttonStateFromEventModifiers", "group__new__in__4__11.html#gacc93a453b03a037ebec4987bc8f30a90", null ],
    [ "buttonStateFromMouseEvent", "group__new__in__4__11.html#ga9e7a18104859beae1f325157d78ea771", null ],
    [ "castKeyboardEvent", "group__new__in__4__11.html#ga72eaa4704e183d6233c4c9cf42df973e", null ],
    [ "castMouseCancelEvent", "group__new__in__4__11.html#gaea47e439b5007888b22a6611e0a34372", null ],
    [ "castMouseDownEvent", "group__new__in__4__11.html#ga0c6b61604f95593156cb21423f653785", null ],
    [ "castMouseEnterEvent", "group__new__in__4__11.html#ga0da14dc430887ec6c938dfbc72a494e3", null ],
    [ "castMouseEvent", "group__new__in__4__11.html#gac58eda1c0fcfecc48bbcd4db4180f01e", null ],
    [ "castMouseExitEvent", "group__new__in__4__11.html#ga3fea1c77f2004d3641a3f1078fef40f7", null ],
    [ "castMouseMoveEvent", "group__new__in__4__11.html#gaeb713ab6ba4e2b6945fdefefb9592e00", null ],
    [ "castMousePositionEvent", "group__new__in__4__11.html#gac7862a08e9b7c64482b9d55e72b09a10", null ],
    [ "castMouseUpEvent", "group__new__in__4__11.html#gae3dfdd4a2dedd1c555cf4646bddc8a28", null ],
    [ "castMouseWheelEvent", "group__new__in__4__11.html#ga5043a8eedce294c63e575beda7bc1adf", null ],
    [ "castZoomGestureEvent", "group__new__in__4__11.html#ga7996f43f0a6f0a855f75e46bc6bd74e9", null ],
    [ "clamp", "namespace_v_s_t_g_u_i.html#afd4c86ba716fdf40d84831822843016a", null ],
    [ "clampNorm", "namespace_v_s_t_g_u_i.html#a97a959bfc6f6e0b27e925f30e3779225", null ],
    [ "convert", "namespace_v_s_t_g_u_i.html#ae4e09ac9b31e63015a2529bb3b001954", null ],
    [ "convert", "namespace_v_s_t_g_u_i.html#a72554073a9cef6518ba0ab5e90f42b09", null ],
    [ "convert", "namespace_v_s_t_g_u_i.html#ada653f3803f48e88c81f1bb8e2fc6aa5", null ],
    [ "doAssert", "namespace_v_s_t_g_u_i.html#a61f906552ad31a1b0edc6d12218fa83d", null ],
    [ "drawClipped", "namespace_v_s_t_g_u_i.html#a61ce8e0954f743f4396fe84df08f0efa", null ],
    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#a2a8b0c5618f1860cc17a9bc00b6c5112", null ],
    [ "dynamicPtrCast", "namespace_v_s_t_g_u_i.html#ac583ee24515aee11772b84e23f974719", null ],
    [ "end", "namespace_v_s_t_g_u_i.html#a72937ea7ab5f5e115688282d8027c68d", null ],
    [ "endianSwap", "namespace_v_s_t_g_u_i.html#a3d6471ce0a87d930ca7d0a6693756463", null ],
    [ "exit", "group__new__in__4__10.html#ga358d2e2397ca11ccd17553e3c40e7901", null ],
    [ "finally", "namespace_v_s_t_g_u_i.html#a96b28b9c9adbba00aae653bd64e5d784", null ],
    [ "findControlForTag", "namespace_v_s_t_g_u_i.html#aac8d4f664427cb963617361dd976bdd5", null ],
    [ "findViewController", "namespace_v_s_t_g_u_i.html#aa776c0b3f1b205a1d8cc6a5741402a74", null ],
    [ "FreeNodePlatformResources", "namespace_v_s_t_g_u_i.html#ac071928df01744b9ab2f020131232c91", null ],
    [ "fromVstVirtualKey", "namespace_v_s_t_g_u_i.html#ad7b564797515bf4a690993a851e8c200", null ],
    [ "getCreatorRegistry", "namespace_v_s_t_g_u_i.html#a3ea024da68ef884d603e29900152fd36", null ],
    [ "getGenericViewFactory", "namespace_v_s_t_g_u_i.html#a10480eb9d1ff4a0aeb886f9186066331", null ],
    [ "getSplitViewController", "namespace_v_s_t_g_u_i.html#ab25dd81cb13ee92511b6bbf80e53397a", null ],
    [ "getTooltipFromView", "namespace_v_s_t_g_u_i.html#a9e2946e83b4d39ca26a82fc37c0b9659", null ],
    [ "getViewController", "namespace_v_s_t_g_u_i.html#a4fe5229a1073206ee8671ea2a88a6408", null ],
    [ "hasAssertionHandler", "namespace_v_s_t_g_u_i.html#ab0411f6642b03599f6d293af2c17079c", null ],
    [ "hasBit", "namespace_v_s_t_g_u_i.html#a64ee641cfa5acff3b6d1640b8034b7e4", null ],
    [ "indexOf", "namespace_v_s_t_g_u_i.html#a0e4aaf51cfebd26f3e39a53656c77812", null ],
    [ "indexOfTest", "namespace_v_s_t_g_u_i.html#a7c163ed0030c8101aa84ef3c41235b38", null ],
    [ "init", "group__new__in__4__10.html#gacb669fbf9e184809ae58b5cfa4741088", null ],
    [ "isLineBreakSeparator", "namespace_v_s_t_g_u_i.html#a175a5c34bf33ae30700d212d3542d8c1", null ],
    [ "isSpace", "namespace_v_s_t_g_u_i.html#ac26b1f35554922a8ffe67f3f75d6cd09", null ],
    [ "isUniformScaled", "namespace_v_s_t_g_u_i.html#a91ded4561f0774517306c07368fd286c", null ],
    [ "joinNearbyInvalidRects", "namespace_v_s_t_g_u_i.html#abf0b326c7d9697dd8c0ce8d29388f87c", null ],
    [ "lastPathComponent", "namespace_v_s_t_g_u_i.html#aa82c6851e0bdb32857e701bedcb1f476", null ],
    [ "MakeCColor", "namespace_v_s_t_g_u_i.html#a881b1a17406575d2fddb02dc4cd162e3", null ],
    [ "makeOptional", "namespace_v_s_t_g_u_i.html#a8ea883f00c2913b47f7fcac1e7f3fb29", null ],
    [ "makeOwned", "namespace_v_s_t_g_u_i.html#a2897be7c30768d8f7835efb5d53a7f3a", null ],
    [ "moveOldFile", "namespace_v_s_t_g_u_i.html#a6565e55a049eec7949351a055020fa3d", null ],
    [ "noEvent", "namespace_v_s_t_g_u_i.html#a3a399ac6c0c4b47c5521578dff18f912", null ],
    [ "normalizedToPlain", "namespace_v_s_t_g_u_i.html#ab79e3708bc6a17f00a5bc9fb2975d18b", null ],
    [ "normalizedToSteps", "namespace_v_s_t_g_u_i.html#ad0c75c525c787dcede75ae5120feea45", null ],
    [ "operator!=", "namespace_v_s_t_g_u_i.html#a000cca3ec3766ffb0bc9faa7cfc2dfc5", null ],
    [ "operator+", "namespace_v_s_t_g_u_i.html#acc62467cef50fee9d0fb8ccb962b7e69", null ],
    [ "operator==", "namespace_v_s_t_g_u_i.html#afc6a4ab99c775dfecbf4d1e5f30e2e49", null ],
    [ "owned", "namespace_v_s_t_g_u_i.html#a395a83d0c66a2ff8e9783438a3dd2e29", null ],
    [ "pathIsAbsolute", "namespace_v_s_t_g_u_i.html#a4a15b00a3f396ff95029b02997bcc78f", null ],
    [ "plainToNormalized", "namespace_v_s_t_g_u_i.html#ac04eb5f1199b0becb385db6f5cd1140a", null ],
    [ "radians", "namespace_v_s_t_g_u_i.html#a570f916012bfd4da75c05e7d6557d21c", null ],
    [ "removeChildNode", "namespace_v_s_t_g_u_i.html#ac0f3df334bb7d3af53dea0baa7962170", null ],
    [ "removeLastPathComponent", "namespace_v_s_t_g_u_i.html#ad8268fce27a595eb6c413d9e3176b0cc", null ],
    [ "renderBitmapOffscreen", "namespace_v_s_t_g_u_i.html#af0b09266cd230c80ad45b8451c8b11d9", null ],
    [ "setAssertionHandler", "namespace_v_s_t_g_u_i.html#a04a819c7a5ef1f7488cfcbd510e4912b", null ],
    [ "setBit", "namespace_v_s_t_g_u_i.html#afc62e7dfbcbd4f90e5ab9a87ec202879", null ],
    [ "shared", "namespace_v_s_t_g_u_i.html#aee219d95a6d17da540c26ef9951feaa5", null ],
    [ "shouldStartDrag", "group__new__in__4__9.html#gab218802ff3016e52ac7dc3abb331945e", null ],
    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a6a973e5421cd9481de68ad5a73909005", null ],
    [ "staticPtrCast", "namespace_v_s_t_g_u_i.html#a1723a75712e38e9b08a4cc7535591ba0", null ],
    [ "stepsToNormalized", "namespace_v_s_t_g_u_i.html#aa21a1186c4869fd7b872418c07f0321b", null ],
    [ "toString", "namespace_v_s_t_g_u_i.html#a1477db6c65effca97f3658df05ad749c", null ],
    [ "toVstKeyCode", "namespace_v_s_t_g_u_i.html#a9ff61fbaceee2ad20764752ba0e2aa6c", null ],
    [ "toVstVirtualKey", "group__new__in__4__11.html#ga36a2c5cf70fdd5d947276ae40e061b3a", null ],
    [ "trim", "namespace_v_s_t_g_u_i.html#a879a9ac72cbabe826e1b928aeba70935", null ],
    [ "unixfyPath", "namespace_v_s_t_g_u_i.html#a89f6f7584b245dc5a4050d2d0db9eecb", null ],
    [ "viewHasTooltip", "namespace_v_s_t_g_u_i.html#a0ed00417e359355e46f35ff8e1e4e52f", null ],
    [ "writeEndianSwap", "namespace_v_s_t_g_u_i.html#a202cedc1a740710d736ef2701d6f8bd6", null ],
    [ "assertionHandler", "namespace_v_s_t_g_u_i.html#ac8534d324abb28a3408624afe03d14df", null ],
    [ "globalFonts", "namespace_v_s_t_g_u_i.html#a468cfdbb3f7b47818718b6cbedd64a25", null ],
    [ "kBlackCColor", "namespace_v_s_t_g_u_i.html#a3a66709c3ab3f7c308dd4dba9ad3174a", null ],
    [ "kBlueCColor", "namespace_v_s_t_g_u_i.html#a2bbb7535524b56ee8c5965959985bee9", null ],
    [ "kCheckBoxTitleMargin", "namespace_v_s_t_g_u_i.html#a130a5153aaf9620f319ecd7533495efd", null ],
    [ "kCKnobMouseStateAttribute", "namespace_v_s_t_g_u_i.html#a3c9e6b56c1987734dcc45d6800a24819", null ],
    [ "kCKnobRangeDefault", "namespace_v_s_t_g_u_i.html#abdbdc1f23dc95c8ddc2f0a3d1eec39ca", null ],
    [ "kCopyrightSymbol", "namespace_v_s_t_g_u_i.html#a6df0832ccd2b58c10fb3ceda5200a2ac", null ],
    [ "kCViewAlphaValueAttrID", "namespace_v_s_t_g_u_i.html#a39923cbb80de0dff010ad945fae1d2fd", null ],
    [ "kCViewAttributeReferencePointer", "namespace_v_s_t_g_u_i.html#a38e418917a1522b93d324c6dd4c6d4f5", null ],
    [ "kCViewBackgroundBitmapAttrID", "namespace_v_s_t_g_u_i.html#aa39a6c617b711bc1bf98edab3c51d2a2", null ],
    [ "kCViewContainerBackgroundOffsetAttribute", "namespace_v_s_t_g_u_i.html#a5bdf34828201105a41bb67431b35798b", null ],
    [ "kCViewContainerDropTargetAttribute", "namespace_v_s_t_g_u_i.html#a2e62b413b0307f1f19a211031d7c0edd", null ],
    [ "kCViewContainerLastDrawnFocusAttribute", "namespace_v_s_t_g_u_i.html#ae2107ebb108b48b6ccb82e122b3a2ef8", null ],
    [ "kCViewContainerMouseDownViewAttribute", "namespace_v_s_t_g_u_i.html#a82df5339d0cfd268607d8074d1e631ed", null ],
    [ "kCViewControllerAttribute", "namespace_v_s_t_g_u_i.html#acf7ab981c035225405c0443f9d796a36", null ],
    [ "kCViewCustomDropTargetAttrID", "namespace_v_s_t_g_u_i.html#a166c5a101cdb6c25330c49de629609ea", null ],
    [ "kCViewDisabledBackgroundBitmapAttrID", "namespace_v_s_t_g_u_i.html#a1d8a8309aa034d88271ce33e68645f61", null ],
    [ "kCViewHitTestPathAttrID", "namespace_v_s_t_g_u_i.html#a66b6dccbb225c9bb73b676f6ea496a4a", null ],
    [ "kCViewMouseableAreaAttrID", "namespace_v_s_t_g_u_i.html#ab09916d8f472e5ac1704779170768269", null ],
    [ "kCViewTooltipAttribute", "namespace_v_s_t_g_u_i.html#a7ae3453188fb48bc33643428d0609b4f", null ],
    [ "kCyanCColor", "namespace_v_s_t_g_u_i.html#ab5fc0227d619f690ef1dc1262560a51a", null ],
    [ "kDefaultOnOffDashLength", "namespace_v_s_t_g_u_i.html#a01525794b22b39f5d884159966f94d02", null ],
    [ "kDegreeSymbol", "namespace_v_s_t_g_u_i.html#a751743297dd5370ecd754f6d5febccaa", null ],
    [ "kGreenCColor", "namespace_v_s_t_g_u_i.html#addd11f9ca62a7318169eefd52f167019", null ],
    [ "kGreyCColor", "namespace_v_s_t_g_u_i.html#a7c0ad4952320483854b054220f51e2c3", null ],
    [ "kInfiniteSymbol", "namespace_v_s_t_g_u_i.html#acb138998c498ba9595e6fc627e0e1625", null ],
    [ "kLineOnOffDash", "namespace_v_s_t_g_u_i.html#acf7c7fcd7c232b20bd8efd0e321dc563", null ],
    [ "kLineSolid", "namespace_v_s_t_g_u_i.html#a2b3c3fce37dcb4d9d39a2ea8b7874fbb", null ],
    [ "kMagentaCColor", "namespace_v_s_t_g_u_i.html#a9e48c6f2fb6d1711696f98eb6491677b", null ],
    [ "kMicroSymbol", "namespace_v_s_t_g_u_i.html#ada29b4c483d851a3275030abb20bc586", null ],
    [ "kMsgLooseFocus", "namespace_v_s_t_g_u_i.html#ac8b81da6ba5c8afef660be42c6b5a7cf", null ],
    [ "kMsgNewFocusView", "namespace_v_s_t_g_u_i.html#af619beb7391e676967b0d19f43012538", null ],
    [ "kMsgOldFocusView", "namespace_v_s_t_g_u_i.html#a51aedb414a3aedcf284e75ee25d0038f", null ],
    [ "kMsgViewSizeChanged", "namespace_v_s_t_g_u_i.html#afd5fc871c1a7968e13353ef6a37a4c73", null ],
    [ "kNormalFont", "namespace_v_s_t_g_u_i.html#aee3a15411fb6ad78249b3cf24672c0d2", null ],
    [ "kNormalFontBig", "namespace_v_s_t_g_u_i.html#a168bcd7a7c55c693ce949a7ef06f10df", null ],
    [ "kNormalFontSmall", "namespace_v_s_t_g_u_i.html#a3f871e1844f1468e221244065b3b1778", null ],
    [ "kNormalFontSmaller", "namespace_v_s_t_g_u_i.html#aa9698310af97ef4b7bce004164f382b2", null ],
    [ "kNormalFontVeryBig", "namespace_v_s_t_g_u_i.html#a0e33ba9d3de542e92889eb1d96a7dc9e", null ],
    [ "kNormalFontVerySmall", "namespace_v_s_t_g_u_i.html#a6c0f7a8e2c3a4c2ad206eae9f76205a3", null ],
    [ "kPerthousandSymbol", "namespace_v_s_t_g_u_i.html#ab3bcc3b2d93952f1328945696b5ee38d", null ],
    [ "kRedCColor", "namespace_v_s_t_g_u_i.html#ab51f8d1326e3178f5983a322a03c502b", null ],
    [ "kRegisteredSymbol", "namespace_v_s_t_g_u_i.html#ad7d483b9c541619eb43ce1d67e608b44", null ],
    [ "kStreamIOError", "namespace_v_s_t_g_u_i.html#a66f8ddf1c498fb64c35b234df6b4ca7b", null ],
    [ "kStreamSeekError", "namespace_v_s_t_g_u_i.html#a5abdcf76a0a0756aacf0f19476f3114b", null ],
    [ "kSymbolFont", "namespace_v_s_t_g_u_i.html#aa3f65a08e37f4b682efaa423b7b4cd35", null ],
    [ "kSystemFont", "namespace_v_s_t_g_u_i.html#a115510fb7313e4cb47c415ffceab6890", null ],
    [ "kTemplateAttributeMaxSize", "namespace_v_s_t_g_u_i.html#a3bc2e657c2067648f97f6ee1f372d92c", null ],
    [ "kTemplateAttributeMinSize", "namespace_v_s_t_g_u_i.html#af52e5e7feb61f5249ab54d4c4bae7722", null ],
    [ "kTrademarkSymbol", "namespace_v_s_t_g_u_i.html#a93ca4a8f9eaa242e51140e84980a0672", null ],
    [ "kTransparentCColor", "namespace_v_s_t_g_u_i.html#ae6cce1dc82a2b77ef46720bc1f8ff1e6", null ],
    [ "kUIDescIdentifier", "namespace_v_s_t_g_u_i.html#ae236b77f044b1580282c2491f956048b", null ],
    [ "kViewNameAttribute", "namespace_v_s_t_g_u_i.html#a293b05bd232342337b39195cbb1ed6a4", null ],
    [ "kWhiteCColor", "namespace_v_s_t_g_u_i.html#a21e9da5a787be82b5c87dd9c2e909c9b", null ],
    [ "kYellowCColor", "namespace_v_s_t_g_u_i.html#a4112c2c08f0b5901bfca25a2fc58d6d4", null ],
    [ "unixPathSeparator", "namespace_v_s_t_g_u_i.html#a1dd448de94cb8e699d0280716db018c8", null ],
    [ "windowsPathSeparator", "namespace_v_s_t_g_u_i.html#a6ebc5182919a5dd7d3f30fd59eb23df3", null ]
];